@@ -48,6 +48,9 @@
 #include <sys/stat.h> /* stat() */
 #include <time.h> /* machine time */
 #ifndef _MSC_VER
+# if !defined(HAVE_BISON_FLEX)
+#  define HAVE_BISON_FLEX /* 21070906 pvn add this definition to automake, currently in CMake */
+# endif /* HAVE_BISON_FLEX */
 # include <unistd.h> /* POSIX stuff */
 #endif /* _MSC_VER */
 #ifndef HAVE_GETOPT_LONG
@@ -81,17 +84,17 @@
 
 /* #define MAIN_PROGRAM_FILE MUST precede #include libnco.h */
 #define MAIN_PROGRAM_FILE
-#ifndef _MSC_VER
+#ifdef HAVE_BISON_FLEX
 # include "ncap.h" /* netCDF arithmetic processor-specific definitions (symbol table, ...) */
-#endif /* _MSC_VER */
+#endif /* !HAVE_BISON_FLEX */
 #include "libnco.h" /* netCDF Operator (NCO) library */
 
-#ifndef _MSC_VER
+#ifdef HAVE_BISON_FLEX
 /* Global variables (keep consistent with global variables declared in ncap.c) */ 
 size_t ncap_ncl_dpt_crr=0UL; /* [nbr] Depth of current #include file (incremented in ncap.l) */
 size_t *ncap_ln_nbr_crr; /* [cnt] Line number (incremented in ncap.l) */
 char **ncap_fl_spt_glb; /* [fl] Script file */
-#endif /* _MSC_VER */
+#endif /* !HAVE_BISON_FLEX */
 
 int 
 main(int argc,char **argv)
@@ -125,7 +128,7 @@ main(int argc,char **argv)
 
   const char * const CVS_Id="$Id$"; 
   const char * const CVS_Revision="$Revision$";
-  const char * const opt_sht_lst="3467Aa:B:bCcD:d:Fg:G:hIL:l:M:m:nNOo:p:rRT:t:v:Ww:xy:-:";
+  const char * const opt_sht_lst="34567Aa:B:bCcD:d:Fg:G:hIL:l:M:m:nNOo:p:rRT:t:v:Ww:xy:-:";
 
   cnk_sct cnk; /* [sct] Chunking structure */
 
@@ -242,9 +245,9 @@ main(int argc,char **argv)
 
   gpe_sct *gpe=NULL; /* [sng] Group Path Editing (GPE) structure */
 
-#ifndef _MSC_VER
+#ifdef HAVE_BISON_FLEX
   prs_sct prs_arg;  /* I/O [sct] Global information required in ncwa parser */
-#endif /* _MSC_VER */
+#endif /* !HAVE_BISON_FLEX */
 
 #ifdef ENABLE_MPI
   /* Declare all MPI-specific variables here */
@@ -321,8 +324,13 @@ main(int argc,char **argv)
     /* Long options with short counterparts */
     {"3",no_argument,0,'3'},
     {"4",no_argument,0,'4'},
-    {"64bit",no_argument,0,'4'},
     {"netcdf4",no_argument,0,'4'},
+    {"5",no_argument,0,'5'},
+    {"64bit_data",no_argument,0,'5'},
+    {"cdf5",no_argument,0,'5'},
+    {"pnetcdf",no_argument,0,'5'},
+    {"64bit_offset",no_argument,0,'6'},
+    {"7",no_argument,0,'7'},
     {"append",no_argument,0,'A'},
     {"average",required_argument,0,'a'},
     {"avg",required_argument,0,'a'},
@@ -376,9 +384,9 @@ main(int argc,char **argv)
     {"normalize-by-tally",no_argument,0,'W',},
     {"exclude",no_argument,0,'x'},
     {"xcl",no_argument,0,'x'},
-    {"weight",no_argument,0,'w'},
-    {"wgt",no_argument,0,'w'},
-    {"wgt_var",no_argument,0,'w'},
+    {"weight",required_argument,0,'w'},
+    {"wgt",required_argument,0,'w'},
+    {"wgt_var",required_argument,0,'w'},
     {"operation",required_argument,0,'y'},
     {"op_typ",required_argument,0,'y'},
     {0,0,0,0}
@@ -496,11 +504,14 @@ main(int argc,char **argv)
     case '3': /* Request netCDF3 output storage format */
       fl_out_fmt=NC_FORMAT_CLASSIC;
       break;
-    case '4': /* Catch-all to prescribe output storage format */
-      if(!strcmp(opt_crr,"64bit")) fl_out_fmt=NC_FORMAT_64BIT; else fl_out_fmt=NC_FORMAT_NETCDF4; 
+    case '4': /* Request netCDF4 output storage format */
+      fl_out_fmt=NC_FORMAT_NETCDF4; 
+      break;
+    case '5': /* Request netCDF3 64-bit offset+data storage (i.e., pnetCDF) format */
+      fl_out_fmt=NC_FORMAT_CDF5;
       break;
     case '6': /* Request netCDF3 64-bit offset output storage format */
-      fl_out_fmt=NC_FORMAT_64BIT;
+      fl_out_fmt=NC_FORMAT_64BIT_OFFSET;
       break;
     case '7': /* Request netCDF4-classic output storage format */
       fl_out_fmt=NC_FORMAT_NETCDF4_CLASSIC;
@@ -520,10 +531,10 @@ main(int argc,char **argv)
       break;
     case 'B': /* Mask string to be parsed */
       msk_cnd_sng=(char *)strdup(optarg);
-#ifdef _MSC_VER
-      (void)fprintf(fp_stdout,"%s: ERROR -B and --mask_condition options unsupported on Windows, which lacks a standard parser and lexer that are free. HINT: Break condition into component -m -T -M switches, e.g., use -m ORO -T lt -M 1.0 instead of -B \"ORO < 1\"\n",nco_prg_nm);
+#ifndef HAVE_BISON_FLEX
+      (void)fprintf(fp_stdout,"%s: ERROR -B and --mask_condition options unsupported because configuration could not find a parser (e.g., Bison) and lexer (e.g., Flex). HINT: Break condition into component -m -T -M switches, e.g., use -m ORO -T lt -M 1.0 instead of -B \"ORO < 1\"\n",nco_prg_nm);
       nco_exit(EXIT_FAILURE);
-#endif /* !_MSC_VER */
+#endif /* HAVE_BISON_FLEX */
       break;
     case 'b': /* [flg] Retain degenerate dimensions */
       flg_rdd=True;
@@ -663,7 +674,7 @@ main(int argc,char **argv)
   trv_tbl_init(&trv_tbl);
 
   /* Parse mask string */
-#ifndef _MSC_VER
+#ifdef HAVE_BISON_FLEX
   if(msk_cnd_sng){
     int cst_zero=0;
     /* Set arguments for scan */
@@ -688,7 +699,7 @@ main(int argc,char **argv)
     ncap_ln_nbr_crr[ncap_ncl_dpt_crr]=1UL; /* [cnt] Line number incremented in ncap.l */
     if(ncap_ncwa_scn(&prs_arg,msk_cnd_sng,&msk_nm,&msk_val,&op_typ_rlt) != NCO_NOERR) nco_exit(EXIT_FAILURE); 
   } /* endif msk_cnd_sng */ 
-#endif /* _MSC_VER */
+#endif /* !HAVE_BISON_FLEX */
 
   /* Ensure we do not attempt to normalize by non-existent weight */
   if(!wgt_nm) NORMALIZE_BY_WEIGHT=False;
